@@ -32,7 +32,7 @@
  *----------------------------------------------------------------------*/
 
 #ifndef lint
-static const char rcsid[] = "$Id: main.c,v 1.28 2005/06/20 16:10:19 sasha Exp $";
+static const char rcsid[] = "$Id: main.c,v 1.33 2007/08/01 14:08:29 vae Exp $";
 #endif
 
 #define INTERN			/* assign all global vars to me */
@@ -1021,6 +1021,9 @@ set_width(unsigned short width)
 
 	XResizeWindow(Xdisplay, TermWin.parent, width, height);
 	resize_window1(width, height);
+#ifdef USE_XIM
+        IMSetStatusPosition();
+#endif
 	scr_clear();
     }
 }
@@ -1037,12 +1040,12 @@ resize_window(XEvent* ev)
 	XConfigureEvent *xconf = &(ev->xconfigure);
 	
 	while( XCheckTypedWindowEvent( Xdisplay, TermWin.parent, ConfigureNotify, ev ) );
-	fprintf( stderr, "config_geom = %dx%d\n", xconf->width, xconf->height );
+	/*fprintf( stderr, "config_geom = %dx%d\n", xconf->width, xconf->height );*/
     resize_window1(xconf->width, xconf->height);
 #if 1
 	XTranslateCoordinates (Xdisplay, TermWin.parent, Xroot, 0, 0, &root_x, &root_y, &wdumm);
 
-	fprintf( stderr, "root_geom = %dx%d%+d%+d, root_size = %dx%d\n", xconf->width, xconf->height, root_x, root_y, XdisplayWidth, XdisplayHeight ); 
+	/*fprintf( stderr, "root_geom = %dx%d%+d%+d, root_size = %dx%d\n", xconf->width, xconf->height, root_x, root_y, XdisplayWidth, XdisplayHeight ); */
 	TermWin.root_x = root_x ; 
 	TermWin.root_y = root_y ; 
 	TermWin.root_width = xconf->width ; 
@@ -1531,7 +1534,11 @@ change_font(int init, const char *fontname)
 	fw = TermWin.font->min_bounds.width; /* can be error !!!! */
 	if( fw > 1000 ) fw = 0 ;  /* added by suggestion from <suchness>*/
 
-	fh = TermWin.font->ascent + TermWin.font->descent;
+#ifdef USE_LINESPACE
+      fh = TermWin.font->ascent + TermWin.font->descent + TermWin.lineSpace;
+#else
+      fh = TermWin.font->ascent + TermWin.font->descent;
+#endif
 
 	if (TermWin.font->min_bounds.width == TermWin.font->max_bounds.width)
 	    TermWin.fprop = 0;	/* Mono-spaced (fixed width) font */
@@ -1647,7 +1654,7 @@ char* font2string( XFontStruct *font, char* old_string )
 	font_name=XGetAtomName(Xdisplay, name_value);
 	if( font_name )
 	{
-          fprintf( stderr, " font found : [%s]\n", font_name );
+          /*fprintf( stderr, " font found : [%s]\n", font_name ); */
 	    old_string = realloc( old_string, strlen( font_name)+1 );
 	    strcpy( old_string, font_name );
 	}
@@ -2006,6 +2013,9 @@ main(int argc, char *argv[])
     rs_geometry = NULL;		/* window geometry */
     rs_minBufferWidth = NULL;
     rs_saveLines = NULL;	/* scrollback buffer [lines] */
+#ifdef USE_LINESPACE
+    rs_lineSpace = NULL;
+#endif
     rs_borderWidth = NULL;
     rs_internal_border = NULL;
     rs_modifier = NULL;	/* modifier */
@@ -2095,7 +2105,8 @@ main(int argc, char *argv[])
 		print_error("can't open display %s", display_name);
 		exit(EXIT_FAILURE);
     }
-	_XA_MwmAtom = XInternAtom(Xdisplay, "_MOTIF_WM_INFO", True);
+  /* changed from _MOTIF_WM_INFO - Vaevictus - gentoo bug #139554 */
+	_XA_MwmAtom = XInternAtom(Xdisplay, "_MOTIF_WM_HINTS", True);
 	_XA_NET_WM_PID = XInternAtom(Xdisplay, "_NET_WM_PID", False);
 	_XROOTPMAP_ID = XInternAtom(Xdisplay, "_XROOTPMAP_ID", False);
 	_XA_NET_SUPPORTING_WM_CHECK = XInternAtom(Xdisplay, "_NET_SUPPORTING_WM_CHECK", False);
@@ -2143,6 +2154,8 @@ main(int argc, char *argv[])
 	aterm_XA_TEXT = XInternAtom(Xdisplay, "TEXT", False);
 	aterm_XA_UTF8_STRING = XInternAtom(Xdisplay, "UTF8_STRING", False);
 	aterm_XA_CLIPBOARD = XInternAtom(Xdisplay, "CLIPBOARD", False);
+	aterm_XA_VT_SELECTION = XInternAtom(Xdisplay, "VT_SELECTION", False);
+	aterm_XA_INCR		  = XInternAtom(Xdisplay, "INCR", False);
 
 	check_extended_wm_hints_support();
 	
@@ -2216,6 +2229,10 @@ main(int argc, char *argv[])
     	TermWin.saveLines = SAVELINES;
     else
         TermWin.saveLines = t;
+#ifdef USE_LINESPACE
+    if (!rs_lineSpace || (TermWin.lineSpace = atoi(rs_lineSpace)) < 0)
+        TermWin.lineSpace = LINESPACE;
+#endif
 
     if (!rs_borderWidth || (t = atoi(rs_borderWidth)) < 0)
         TermWin.borderWidth = BORDERWIDTH;
@@ -2272,6 +2289,9 @@ main(int argc, char *argv[])
 	    rs_mfont[i] = def_mfontName[i];
 #endif
     }
+#ifdef USE_XIM
+    TermWin.fontset = NULL;
+#endif
 
 #ifdef XTERM_REVERSE_VIDEO
 /* this is how xterm implements reverseVideo */
