@@ -1,6 +1,6 @@
 /* Include prototypes for all files */
 /*
- * $Id: protos.h,v 1.2 2001/03/26 17:26:10 sashav Exp $
+ * $Id: protos.h,v 1.1.1.1 2004/11/10 17:21:47 sasha Exp $
  */
 #include "command.pro"
 #include "graphics.pro"
@@ -12,11 +12,7 @@
 #include "rmemset.pro"
 #include "screen.pro"
 #include "thai.pro"
-#ifdef NEXT_SCROLLBAR
-# include "scrollbar2.pro"
-#else
 # include "scrollbar.pro"
-#endif
 #ifdef UTMP_SUPPORT
 #include "utmp.pro"
 #endif
