@@ -1,5 +1,5 @@
 /*
- * $Id: rxvt.h,v 1.16 2005/06/20 16:10:19 sasha Exp $
+ * $Id: rxvt.h,v 1.18 2006/02/17 21:35:37 sasha Exp $
  */
 
 #ifndef _RXVT_H			/* include once only */
@@ -314,6 +314,9 @@ typedef struct {
 		    ncol, nrow,	/* window size [characters]                 */
 		    bcol,	/* current number of columns in the buffer  */
 		    min_bcol,	/* minimum horizontal columns in the buffer */
+#ifdef USE_LINESPACE
+                    lineSpace,  /* linespace             */
+#endif
 		    focus,	/* window has focus                         */
 		    saveLines,	/* number of lines that fit in scrollback   */
 		    borderWidth,/* number of pixels in window border        */
@@ -328,6 +331,9 @@ typedef struct {
 #ifdef MULTICHAR_SET
     XFontStruct    *mfont;	/* Multichar font structure                 */
 #endif
+#ifdef USE_XIM
+    XFontSet fontset;
+#endif
 #if defined(BACKGROUND_IMAGE) || defined(TRANSPARENT) || defined(_MYSTYLE_)
     BackgroundInfo background;
 #endif
@@ -1041,6 +1047,9 @@ EXTERN const char      *rs_iconName;	/* icon name for window */
 EXTERN const char      *rs_geometry;	/* window geometry */
 EXTERN const char      *rs_minBufferWidth; /* minimum buffer width - so we can scroll horizontally */
 EXTERN const char      *rs_saveLines;	/* scrollback buffer [lines] */
+#ifdef USE_LINESPACE
+EXTERN const char      *rs_lineSpace; /* line space [pixels] */
+#endif
 EXTERN const char      *rs_borderWidth; /* border width [pixels] */
 EXTERN const char      *rs_internal_border; /* internal border width [pixels] */
 EXTERN const char      *rs_cutchars;	/* chars for selection boundaries */
@@ -1063,6 +1072,10 @@ EXTERN const char      *rs_boldFont;
 #ifdef PRINTPIPE
 EXTERN const char      *rs_print_pipe;
 #endif
+#ifdef USE_XIM
+EXTERN const char      *rs_preeditType;
+EXTERN const char      *rs_inputMethod;
+#endif
 #ifndef NO_BRIGHTCOLOR
 EXTERN unsigned int	colorfgbg;
 #endif
@@ -1097,6 +1110,9 @@ EXTERN Atom     		aterm_XA_TEXT;
 EXTERN Atom     		_XA_COMPAUND_TEXT;
 EXTERN Atom     		aterm_XA_UTF8_STRING;
 EXTERN Atom     		aterm_XA_CLIPBOARD;
+EXTERN Atom     		aterm_XA_VT_SELECTION;
+EXTERN Atom     		aterm_XA_INCR;		   
+
 
 
 /*
