@@ -35,7 +35,7 @@
  *----------------------------------------------------------------------*/
 
 #ifndef lint
-static const char rcsid[] = "$Id: xdefaults.c,v 1.4 2005/06/03 20:11:55 sasha Exp $";
+static const char rcsid[] = "$Id: xdefaults.c,v 1.5 2005/12/06 17:08:44 sasha Exp $";
 #endif
 
 #include "rxvt.h"		/* NECESSARY */
@@ -273,6 +273,11 @@ static const struct {
     STRG(rs_multichar_encoding, "multichar_encoding", "km", "mode",
          "multiple-character font encoding; mode = eucj | sjis | big5"),
 #endif				/* MULTICHAR_SET */
+#ifdef USE_XIM
+    STRG(rs_preeditType, "preeditType", "pt", "style",
+        "input style of input method; style = OverTheSpot | OffTheSpot | Root"),
+    STRG(rs_inputMethod, "inputMethod", "im", "name", "name of input method"),
+#endif                         /* USE_XIM */
 #ifdef GREEK_SUPPORT
     STRG(rs_greek_keyboard, "greek_keyboard", "grk", "mode",
          "greek keyboard mapping; mode = iso | ibm"),
@@ -315,6 +320,10 @@ static const struct {
          "minimum number of columns stored in buffer"),
     STRG(rs_saveLines, "saveLines", "sl", "number",
          "number of scrolled lines to save"),
+#ifdef USE_LINESPACE
+    STRG(rs_lineSpace, "lineSpace", "lsp", "number",
+         "line space"),
+#endif
     BOOL(rs_utmpInhibit, "utmpInhibit", "ut", Opt_utmpInhibit,
          "utmp inhibit"),
     BOOL(rs_visualBell, "visualBell", "vb", Opt_visualBell, "visual bell"),
